# TODOs

- [ ] Add peak picking using pyopenms 
- [ ] Add public base conformer model
- [ ] Add DreamDIA scoring model
- [ ] Add gauss smoothing to visualization display. See [plotter.py#L169](https://github.com/Roestlab/massseer/blob/ebae2f529262e5b1a435f23432d1b4c30b7ec456/massseer/plotter.py#L169) and [plotting_ui.py#L52](https://github.com/Roestlab/massseer/blob/ebae2f529262e5b1a435f23432d1b4c30b7ec456/massseer/plotting_ui.py#L52)
- [ ] Generate concensus chrom traces per transition
- [ ] Docker / or just ssh port
- [ ] Make available on PyPi closer to time of publication
- [ ] Generate an exectuable

# In Progress
- [ ] Major refactoring of code base. For main refactoring branch, see patch/masterRefactor
- [ ] raw mzML data loading
- [ ] DIA-NN results inspection on the raw data

# Future TODOs?


- [ ] ~~raw .d data loading using alphatims api~~
- [ ] Add a bruker .d loader using opentims

# Completed

- [x] ~~Fix interactivity reseting when certain options are selecting, protein and peptide selection boxes get reset~~
- [x] ~~Add unit tests~~
- [x] ~~Small dataset for testing~~
- [x] ~~Add colors for different peak boundaries~~
- [x] ~~Implement plotting PyProphet boundaries and scores~~
- [x] ~~Add grid plot layout if multiple files are loaded~~
- [x] ~~scale intensities of individual traces for chromatograms~~
